@@ -26,23 +26,19 @@ def human( delta, precision = 1 ):
 def test():
     """Test and example usage"""
     from datetime import datetime
-
-    d1 = datetime( year = 2009, month=5, day=4, hour=6, minute=54, second=33, microsecond=4000 )
-    d2 = datetime( year = 2011, month=10, day=6, hour=8, minute=55, second=36 )
-
+    d1 = datetime( 
+      year = 2009, 
+      month=5,
+      day=4,
+      hour=6,
+      minute=54,
+      second=33,
+      microsecond=4000
+     )
+    d2 = datetime.now()
     delta = d2 - d1
-
+    print 'This is just the ago.py test:'
     print delta2dict( delta )
-    print 'Created ' + human( delta ) + ' ago.'
-    print 'Created ' + human( delta, 3 ) + ' ago.'
-    print 'Created ' + human( delta, 6 ) + ' ago.'
-
-    d3 = datetime.now()
-    delta = d3 - d2
-
-    print 'Posted ' + human( delta ) + ' ago'
     print 'Commented ' + human( delta, 3 ) + ' ago'
-    print 'Edited ' + human( delta, 6 ) + ' ago'
 
-if __name__ == "__main__":
-    test()
+if __name__ == "__main__": test()
